import { ChartSOP } from './chartsop';

export class ChartSeriesSOP {
  public seriesIndex = -1;

  /**
   * Get a chart series SOP class based on series name to encapsulate series index which other methods can reuse to further query chart series data.
   *
   * @param chartSOP Chart SOP class object
   * @param seriesName Series name to query
   * @returns If series found return a ChartSeriesSOP object else return undefined
   */
  public static async getChartSeries(chartSOP: ChartSOP, seriesName: string): Promise<ChartSeriesSOP|undefined> {
    const legendList = await chartSOP.getChartLegend().getLegendGroupListItems(0);

    for (let i = 0; i < legendList.length ; i++) {
      if (legendList[i] === seriesName) {
        return new ChartSeriesSOP(i);
      }
    }
    return undefined;
  }

  public constructor(seriesIndex: number) {
    this.seriesIndex = seriesIndex;
  }
}
